@@ -28,7 +28,7 @@ func (e *base64Encoder) PrintLeadingContent(_ io.Writer, _ string) error {
 
 func (e *base64Encoder) Encode(writer io.Writer, node *CandidateNode) error {
 	if node.guessTagFromCustomType() != "!!str" {
-		return fmt.Errorf("cannot encode %v as base64, can only operate on strings. Please first pipe through another encoding operator to convert the value to a string", node.Tag)
+		return fmt.Errorf("cannot encode %v as base64, can only operate on strings", node.Tag)
 	}
 	_, err := writer.Write([]byte(e.encoding.EncodeToString([]byte(node.Value))))
 	return err
