@@ -310,6 +310,15 @@ var addOperatorScenarios = []expressionScenario{
 			"D0, P[], (!!map)::a: !cat Saturday, 15-Dec-01 at 6:00AM GMT\n",
 		},
 	},
+	{
+		skipDoc:        true,
+		description:    "Add to empty",
+		subdescription: "should behave like null",
+		expression:     `.nada + "cat"`,
+		expected: []string{
+			"D0, P[], (!!str)::cat\n",
+		},
+	},
 	{
 		description:    "Add to null",
 		subdescription: "Adding to null simply returns the rhs",
