@@ -171,7 +171,7 @@ var propertyScenarios = []formatScenario{
 	},
 	{
 		description:    "Encode properties - custom separator",
-		subdescription: "Use the --properties-customer-separator flag to specify your own key/value separator.",
+		subdescription: "Use the --properties-separator flag to specify your own key/value separator.",
 		input:          samplePropertiesYaml,
 		expected:       expectedPropertiesUnwrappedCustomSeparator,
 		scenarioType:   "encode-custom-separator",
@@ -227,7 +227,14 @@ var propertyScenarios = []formatScenario{
 		expected:     "- person\n- name\n",
 		scenarioType: "decode",
 	},
-
+	{
+		description:    "Decode properties: numbers",
+		subdescription: "All values are assumed to be strings when parsing properties, but you can use the `from_yaml` operator on all the strings values to autoparse into the correct type.",
+		input:          "a.b = 10",
+		expression:     " (.. | select(tag == \"!!str\")) |= from_yaml",
+		expected:       "a:\n  b: 10\n",
+		scenarioType:   "decode",
+	},
 	{
 		description:    "Decode properties - array should be a map",
 		subdescription: "If you have a numeric map key in your property files, use array_to_map to convert them to maps.",
@@ -312,12 +319,13 @@ func documentUnwrappedEncodePropertyScenario(w *bufio.Writer, s formatScenario)
 	prefs := NewDefaultPropertiesPreferences()
 	useArrayBracketsFlag := ""
 	useCustomSeparatorFlag := ""
-	if s.scenarioType == "encode-array-brackets" {
+	switch s.scenarioType {
+	case "encode-array-brackets":
 		useArrayBracketsFlag = " --properties-array-brackets"
 		prefs.UseArrayBrackets = true
-	} else if s.scenarioType == "encode-custom-separator" {
+	case "encode-custom-separator":
 		prefs.KeyValueSeparator = " :@ "
-		useCustomSeparatorFlag = ` --properties-customer-separator=" :@ "`
+		useCustomSeparatorFlag = ` --properties-separator=" :@ "`
 	}
 
 	if expression != "" {
